@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.1000';
+our $VERSION = '0.1001';
 
 use strict;
 use warnings;
@@ -236,7 +236,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.1000
+version 0.1001
 
 =head1 SYNOPSIS
 
@@ -249,14 +249,17 @@ version 0.1000
 
   my $score = setup_score( bpm => 120, etc => '...', );
 
+  my $ticks = ticks($score);
+  my $half = 'd' . ( $size / 2 * $ticks );
+
   set_time_sig( $score, '5/4' );
 
   set_chan_patch( $score, 0, 1 );
 
   my @notes = midi_format('C','C#','Db','D'); # C, Cs, Df, D
 
-  $score->n('wn', @notes);         # MIDI::Simple functionality
-  $score->write_score('some.mid'); # MIDI::Simple functionality
+  $score->n( $half, @notes );      # MIDI::Simple functionality
+  $score->write_score('some.mid'); # "
 
 =head1 DESCRIPTION
 
